// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

var DotNetEntropyLib = {
    $DOTNETENTROPY: {
        // batchedQuotaMax is the max number of bytes as specified by the api spec.
        // If the byteLength of array is greater than 65536, throw a QuotaExceededError and terminate the algorithm.
        // https://www.w3.org/TR/WebCryptoAPI/#Crypto-method-getRandomValues
        batchedQuotaMax: 65536,
        getBatchedRandomValues: function (buffer, bufferLength) {
            // for modern web browsers
            // map the work array to the memory buffer passed with the length
            for (var i = 0; i < bufferLength; i += this.batchedQuotaMax) {
                var view = new Uint8Array(Module.HEAPU8.buffer, buffer + i, Math.min(bufferLength - i, this.batchedQuotaMax));
                crypto.getRandomValues(view)
            }
        }
    },
    dotnet_browser_entropy : function (buffer, bufferLength) {
        // check that we have crypto available
        if (typeof crypto === 'object' && typeof crypto['getRandomValues'] === 'function') {
            DOTNETENTROPY.getBatchedRandomValues(buffer, bufferLength)
            return 0;
        } else {
            // we couldn't find a proper implementation, as Math.random() is not suitable
            // instead of aborting here we will return and let managed code handle the message
            return -1;
        }
    },
};

autoAddDeps(DotNetEntropyLib, '$DOTNETENTROPY')
mergeInto(LibraryManager.library, DotNetEntropyLib)

// SIG // Begin signature block
// SIG // MIIpGgYJKoZIhvcNAQcCoIIpCzCCKQcCAQExDzANBglg
// SIG // hkgBZQMEAgEFADB3BgorBgEEAYI3AgEEoGkwZzAyBgor
// SIG // BgEEAYI3AgEeMCQCAQEEEBDgyQbOONQRoqMAEEvTUJAC
// SIG // AQACAQACAQACAQACAQAwMTANBglghkgBZQMEAgEFAAQg
// SIG // He0Yy7K+G59QXMN5sHHtOtGJyoFg0Ie3YpqLi1MNoKeg
// SIG // gg3lMIIGYzCCBEugAwIBAgITMwAAA9N2adyA7AGiQwAA
// SIG // AAAD0zANBgkqhkiG9w0BAQwFADB+MQswCQYDVQQGEwJV
// SIG // UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
// SIG // UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBv
// SIG // cmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBT
// SIG // aWduaW5nIFBDQSAyMDExMB4XDTI0MDIyMjIwMjU1M1oX
// SIG // DTI1MDIxOTIwMjU1M1owYzELMAkGA1UEBhMCVVMxEzAR
// SIG // BgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
// SIG // bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
// SIG // bjENMAsGA1UEAxMELk5FVDCCAaIwDQYJKoZIhvcNAQEB
// SIG // BQADggGPADCCAYoCggGBAKJr3WFboo8hjvYLGY3tI6in
// SIG // 98ttqRApdb+QVUtt4qzOjUU6jzJlR6iWCzkQ6U4ZNeAY
// SIG // 5j5ulAqD5Mx3+hzxMp4UULNmq6FF/8oiCEqhbcYJSlys
// SIG // pVtRb7GO8XUSKv5wVV1hNrmpnzOx4n2u90eZ+ehFBuDc
// SIG // cISaiYFtrbQZCS9hZXxoeSyV86iVs9QaetHojvUytJbj
// SIG // tem7TWJvvaDDosYeRaX2wDtTaAJVSc0X4O3wIHazcUFW
// SIG // P1dou65fB/M4L7oCyEGbeqiRrDE4ksyFF9CVAe45UlIc
// SIG // x9b/8gFpV9YrLGgC3XQlZSYDW0ZF2hC1N8CJzQJrilYj
// SIG // kgNOsVJbDHmfo6L9IErSlhESxsnjDNmHfexUPtrdpHR2
// SIG // 1y4tXouxMlGwySrgjvoTrB5591LkXOOkGu7GrGDKAyaI
// SIG // YFKhwOIalmZ13amE/wZxvxwYZJSEMukp5Inl4fjxpa95
// SIG // o/UTsNorMJuKDeVb2mx7bdyL9hLE5W0e1y55JjKFQhMk
// SIG // zAKCTQIDAQABo4IBczCCAW8wHwYDVR0lBBgwFgYKKwYB
// SIG // BAGCN0wIAQYIKwYBBQUHAwMwHQYDVR0OBBYEFE2mlO7W
// SIG // 4hvp78Q62SxRXXxDhfwBMEUGA1UdEQQ+MDykOjA4MR4w
// SIG // HAYDVQQLExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xFjAU
// SIG // BgNVBAUTDTQ2NDIyMys1MDIwODIwHwYDVR0jBBgwFoAU
// SIG // SG5k5VAF04KqFzc3IrVtqMp1ApUwVAYDVR0fBE0wSzBJ
// SIG // oEegRYZDaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3Br
// SIG // aW9wcy9jcmwvTWljQ29kU2lnUENBMjAxMV8yMDExLTA3
// SIG // LTA4LmNybDBhBggrBgEFBQcBAQRVMFMwUQYIKwYBBQUH
// SIG // MAKGRWh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2lv
// SIG // cHMvY2VydHMvTWljQ29kU2lnUENBMjAxMV8yMDExLTA3
// SIG // LTA4LmNydDAMBgNVHRMBAf8EAjAAMA0GCSqGSIb3DQEB
// SIG // DAUAA4ICAQB3r7H5qjR/FMblgKoQkNcyxHetl73OlwKt
// SIG // Uo17y5RBmB4IScr/hNt1wm55xj+HYUXyBXD2nCCcxJmC
// SIG // BpJr4WCXtqBP6YPuOo7lFMzFYVi+Q9ck8TOxiaLyJP7G
// SIG // 3IBsyHiHUhIoay7rgpFO0/de0TQ0NU0oCXmgMT6aw6rL
// SIG // nOuazEKUQZW1trU6TmqwC6aFOIRFpPeYxp/K1b9j5XHD
// SIG // 930AOkIlHXe+20WRPvfcph6uZ/Loak9IkJ4hs7wA4rHr
// SIG // xbBwztQFAblZfPmQyFqQLYPP1GpVmZXSdEHzTBKn88kW
// SIG // NbLC44mAhkVREdiATG2B2mecJDZXymFH4oTJw64cBH1D
// SIG // QIdkiubrI46zE9Utuk4LwO74cQUcwH+4qJbDsxBjoLIk
// SIG // +yesxZmaJWgqyxHZGZe+abmkbQpGzUJwd5TyH45Yb5HR
// SIG // DIpjKjbbjskVBY9d2zJGoh3v1sZ3xPdiO5sMmmYZwjr4
// SIG // 5IX/CiQxWzntUY86ocANs0cDRKRvpvma/cbLrakNLuXd
// SIG // ciuYY8uQvTpKwtwj4IcVZrXAIV+NuE297VOcgI60JFZ9
// SIG // jnPwFnRvtj7EKNY3dpZPP8NUnEAUTEr6X3TRd20wUgsa
// SIG // yah8aGYCtyz7XmhHsXqCTrtquP2L22dAumcvLUazDIBB
// SIG // YSoVWxWDfF8CqPLTzXWcTiVreXz5wxtfGjCCB3owggVi
// SIG // oAMCAQICCmEOkNIAAAAAAAMwDQYJKoZIhvcNAQELBQAw
// SIG // gYgxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5n
// SIG // dG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVN
// SIG // aWNyb3NvZnQgQ29ycG9yYXRpb24xMjAwBgNVBAMTKU1p
// SIG // Y3Jvc29mdCBSb290IENlcnRpZmljYXRlIEF1dGhvcml0
// SIG // eSAyMDExMB4XDTExMDcwODIwNTkwOVoXDTI2MDcwODIx
// SIG // MDkwOVowfjELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldh
// SIG // c2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNV
// SIG // BAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEoMCYGA1UE
// SIG // AxMfTWljcm9zb2Z0IENvZGUgU2lnbmluZyBQQ0EgMjAx
// SIG // MTCCAiIwDQYJKoZIhvcNAQEBBQADggIPADCCAgoCggIB
// SIG // AKvw+nIQHC6t2G6qghBNNLrytlghn0IbKmvpWlCquAY4
// SIG // GgRJun/DDB7dN2vGEtgL8DjCmQawyDnVARQxQtOJDXlk
// SIG // h36UYCRsr55JnOloXtLfm1OyCizDr9mpK656Ca/XllnK
// SIG // YBoF6WZ26DJSJhIv56sIUM+zRLdd2MQuA3WraPPLbfM6
// SIG // XKEW9Ea64DhkrG5kNXimoGMPLdNAk/jj3gcN1Vx5pUkp
// SIG // 5w2+oBN3vpQ97/vjK1oQH01WKKJ6cuASOrdJXtjt7UOR
// SIG // g9l7snuGG9k+sYxd6IlPhBryoS9Z5JA7La4zWMW3Pv4y
// SIG // 07MDPbGyr5I4ftKdgCz1TlaRITUlwzluZH9TupwPrRkj
// SIG // hMv0ugOGjfdf8NBSv4yUh7zAIXQlXxgotswnKDglmDlK
// SIG // Ns98sZKuHCOnqWbsYR9q4ShJnV+I4iVd0yFLPlLEtVc/
// SIG // JAPw0XpbL9Uj43BdD1FGd7P4AOG8rAKCX9vAFbO9G9RV
// SIG // S+c5oQ/pI0m8GLhEfEXkwcNyeuBy5yTfv0aZxe/CHFfb
// SIG // g43sTUkwp6uO3+xbn6/83bBm4sGXgXvt1u1L50kppxMo
// SIG // pqd9Z4DmimJ4X7IvhNdXnFy/dygo8e1twyiPLI9AN0/B
// SIG // 4YVEicQJTMXUpUMvdJX3bvh4IFgsE11glZo+TzOE2rCI
// SIG // F96eTvSWsLxGoGyY0uDWiIwLAgMBAAGjggHtMIIB6TAQ
// SIG // BgkrBgEEAYI3FQEEAwIBADAdBgNVHQ4EFgQUSG5k5VAF
// SIG // 04KqFzc3IrVtqMp1ApUwGQYJKwYBBAGCNxQCBAweCgBT
// SIG // AHUAYgBDAEEwCwYDVR0PBAQDAgGGMA8GA1UdEwEB/wQF
// SIG // MAMBAf8wHwYDVR0jBBgwFoAUci06AjGQQ7kUBU7h6qfH
// SIG // MdEjiTQwWgYDVR0fBFMwUTBPoE2gS4ZJaHR0cDovL2Ny
// SIG // bC5taWNyb3NvZnQuY29tL3BraS9jcmwvcHJvZHVjdHMv
// SIG // TWljUm9vQ2VyQXV0MjAxMV8yMDExXzAzXzIyLmNybDBe
// SIG // BggrBgEFBQcBAQRSMFAwTgYIKwYBBQUHMAKGQmh0dHA6
// SIG // Ly93d3cubWljcm9zb2Z0LmNvbS9wa2kvY2VydHMvTWlj
// SIG // Um9vQ2VyQXV0MjAxMV8yMDExXzAzXzIyLmNydDCBnwYD
// SIG // VR0gBIGXMIGUMIGRBgkrBgEEAYI3LgMwgYMwPwYIKwYB
// SIG // BQUHAgEWM2h0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9w
// SIG // a2lvcHMvZG9jcy9wcmltYXJ5Y3BzLmh0bTBABggrBgEF
// SIG // BQcCAjA0HjIgHQBMAGUAZwBhAGwAXwBwAG8AbABpAGMA
// SIG // eQBfAHMAdABhAHQAZQBtAGUAbgB0AC4gHTANBgkqhkiG
// SIG // 9w0BAQsFAAOCAgEAZ/KGpZjgVHkaLtPYdGcimwuWEeFj
// SIG // kplCln3SeQyQwWVfLiw++MNy0W2D/r4/6ArKO79HqaPz
// SIG // adtjvyI1pZddZYSQfYtGUFXYDJJ80hpLHPM8QotS0LD9
// SIG // a+M+By4pm+Y9G6XUtR13lDni6WTJRD14eiPzE32mkHSD
// SIG // jfTLJgJGKsKKELukqQUMm+1o+mgulaAqPyprWEljHwlp
// SIG // blqYluSD9MCP80Yr3vw70L01724lruWvJ+3Q3fMOr5ko
// SIG // l5hNDj0L8giJ1h/DMhji8MUtzluetEk5CsYKwsatruWy
// SIG // 2dsViFFFWDgycScaf7H0J/jeLDogaZiyWYlobm+nt3TD
// SIG // QAUGpgEqKD6CPxNNZgvAs0314Y9/HG8VfUWnduVAKmWj
// SIG // w11SYobDHWM2l4bf2vP48hahmifhzaWX0O5dY0HjWwec
// SIG // hz4GdwbRBrF1HxS+YWG18NzGGwS+30HHDiju3mUv7Jf2
// SIG // oVyW2ADWoUa9WfOXpQlLSBCZgB/QACnFsZulP0V3HjXG
// SIG // 0qKin3p6IvpIlR+r+0cjgPWe+L9rt0uX4ut1eBrs6jeZ
// SIG // eRhL/9azI2h15q/6/IvrC4DqaTuv/DDtBEyO3991bWOR
// SIG // PdGdVk5Pv4BXIqF4ETIheu9BCrE/+6jMpF3BoYibV3FW
// SIG // TkhFwELJm3ZbCoBIa/15n8G9bW1qyVJzEw16UM0xghqN
// SIG // MIIaiQIBATCBlTB+MQswCQYDVQQGEwJVUzETMBEGA1UE
// SIG // CBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEe
// SIG // MBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSgw
// SIG // JgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBTaWduaW5nIFBD
// SIG // QSAyMDExAhMzAAAD03Zp3IDsAaJDAAAAAAPTMA0GCWCG
// SIG // SAFlAwQCAQUAoIGuMBkGCSqGSIb3DQEJAzEMBgorBgEE
// SIG // AYI3AgEEMBwGCisGAQQBgjcCAQsxDjAMBgorBgEEAYI3
// SIG // AgEVMC8GCSqGSIb3DQEJBDEiBCCk0LbOeo0Jl3UzqyYc
// SIG // R3jw0T+iGBzKrXSBXSbuitilgzBCBgorBgEEAYI3AgEM
// SIG // MTQwMqAUgBIATQBpAGMAcgBvAHMAbwBmAHShGoAYaHR0
// SIG // cDovL3d3dy5taWNyb3NvZnQuY29tMA0GCSqGSIb3DQEB
// SIG // AQUABIIBgJxBuL6753Wjjv56xg8VzPXFcJ6Tmv9LrGcq
// SIG // hvPe+iGEB5xUKag2cBOUNGx/csuBWPCEaEJegx3bkPaV
// SIG // KlogDn+YeI8GCfgJCT+/0V5q+Qd2WTaGKvKAjgRCPfLg
// SIG // xbqcCXK2cx516w8NAq1269pOsfoM5NVw4muGiv8rlnul
// SIG // 9oSR9LboxC6R4v3r/NCVzOHOLw7BOfLY0EszRzdqOC4m
// SIG // g0B3N4OWwnUB3EL1ieRbXiDZJC1EZCFxi3QxffFXVhDL
// SIG // nkm2WUuzREYTw1vX4JWO+HwoKBxz1OdnoEQr5NMLtaWR
// SIG // uR9e783N0LXktxE/tYnWM7fngRhcqdjp3L5TqBBTwRFX
// SIG // qiS+vQ11BAAnxE7WfXLAU5E5PIZtE3Ej2NXuy+b48uTv
// SIG // iVRXDNtb+7HIsIyIyxjhMmBzj+hqPyulkD7LKA+QroUC
// SIG // 8t5WJw4F+KTP/y1HhWCqZhIyEfEJ9FMBTcwrqOwr9Y+U
// SIG // cebXZ0zwXmv7Prv/y0LHbJp29h3iqrkVvvAq5KGCF5cw
// SIG // gheTBgorBgEEAYI3AwMBMYIXgzCCF38GCSqGSIb3DQEH
// SIG // AqCCF3AwghdsAgEDMQ8wDQYJYIZIAWUDBAIBBQAwggFS
// SIG // BgsqhkiG9w0BCRABBKCCAUEEggE9MIIBOQIBAQYKKwYB
// SIG // BAGEWQoDATAxMA0GCWCGSAFlAwQCAQUABCCsXOHWwBVC
// SIG // AKqRcUm5rwITG90OHMOZrpa4RS5DPWUybAIGZhgU96HT
// SIG // GBMyMDI0MDQzMDAzNDgxMy45NTZaMASAAgH0oIHRpIHO
// SIG // MIHLMQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGlu
// SIG // Z3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMV
// SIG // TWljcm9zb2Z0IENvcnBvcmF0aW9uMSUwIwYDVQQLExxN
// SIG // aWNyb3NvZnQgQW1lcmljYSBPcGVyYXRpb25zMScwJQYD
// SIG // VQQLEx5uU2hpZWxkIFRTUyBFU046OTYwMC0wNUUwLUQ5
// SIG // NDcxJTAjBgNVBAMTHE1pY3Jvc29mdCBUaW1lLVN0YW1w
// SIG // IFNlcnZpY2WgghHtMIIHIDCCBQigAwIBAgITMwAAAe+J
// SIG // P1ahWMyo2gABAAAB7zANBgkqhkiG9w0BAQsFADB8MQsw
// SIG // CQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQ
// SIG // MA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9z
// SIG // b2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1NaWNyb3Nv
// SIG // ZnQgVGltZS1TdGFtcCBQQ0EgMjAxMDAeFw0yMzEyMDYx
// SIG // ODQ1NDhaFw0yNTAzMDUxODQ1NDhaMIHLMQswCQYDVQQG
// SIG // EwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UE
// SIG // BxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENv
// SIG // cnBvcmF0aW9uMSUwIwYDVQQLExxNaWNyb3NvZnQgQW1l
// SIG // cmljYSBPcGVyYXRpb25zMScwJQYDVQQLEx5uU2hpZWxk
// SIG // IFRTUyBFU046OTYwMC0wNUUwLUQ5NDcxJTAjBgNVBAMT
// SIG // HE1pY3Jvc29mdCBUaW1lLVN0YW1wIFNlcnZpY2UwggIi
// SIG // MA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQCjC1ji
// SIG // nwzgHwhOakZqy17oE4BIBKsm5kX4DUmCBWI0lFVpEiK5
// SIG // mZ2Kh59soL4ns52phFMQYGG5kypCipungwP9Nob4VGVE
// SIG // 6aoMo5hZ9NytXR5ZRgb9Z8NR6EmLKICRhD4sojPMg/Rn
// SIG // GRTcdf7/TYvyM10jLjmLyKEegMHfvIwPmM+AP7hzQLfE
// SIG // xDdqCJ2u64Gd5XlnrFOku5U9jLOKk1y70c+Twt04/RLq
// SIG // ruv1fGP8LmYmtHvrB4TcBsADXSmcFjh0VgQkX4zXFwqn
// SIG // IG8rgY+zDqJYQNZP8O1Yo4kSckHT43XC0oM40ye2+9l/
// SIG // rTYiDFM3nlZe2jhtOkGCO6GqiTp50xI9ITpJXi0vEek8
// SIG // AejT4PKMEO2bPxU63p63uZbjdN5L+lgIcCNMCNI0SIop
// SIG // S4gaVR4Sy/IoDv1vDWpe+I28/Ky8jWTeed0O3HxPJMZq
// SIG // X4QB3I6DnwZrHiKn6oE38tgBTCCAKvEoYOTg7r2lF0Iu
// SIG // bt/3+VPvKtTCUbZPFOG8jZt9q6AFodlvQntiolYIYtqS
// SIG // rLyXAQIlXGhZ4gNcv4dv1YAilnbWA9CsnYh+OKEFr/4w
// SIG // 4M69lI+yaoZ3L/t/UfXpT/+yc7hS/FolcmrGFJTBYlS4
// SIG // nE1cuKblwZ/UOG26SLhDONWXGZDKMJKN53oOLSSk4ldR
// SIG // 0HlsbT4heLlWlOElJQIDAQABo4IBSTCCAUUwHQYDVR0O
// SIG // BBYEFO1MWqKFwrCbtrw9P8A63bAVSJzLMB8GA1UdIwQY
// SIG // MBaAFJ+nFV0AXmJdg/Tl0mWnG1M1GelyMF8GA1UdHwRY
// SIG // MFYwVKBSoFCGTmh0dHA6Ly93d3cubWljcm9zb2Z0LmNv
// SIG // bS9wa2lvcHMvY3JsL01pY3Jvc29mdCUyMFRpbWUtU3Rh
// SIG // bXAlMjBQQ0ElMjAyMDEwKDEpLmNybDBsBggrBgEFBQcB
// SIG // AQRgMF4wXAYIKwYBBQUHMAKGUGh0dHA6Ly93d3cubWlj
// SIG // cm9zb2Z0LmNvbS9wa2lvcHMvY2VydHMvTWljcm9zb2Z0
// SIG // JTIwVGltZS1TdGFtcCUyMFBDQSUyMDIwMTAoMSkuY3J0
// SIG // MAwGA1UdEwEB/wQCMAAwFgYDVR0lAQH/BAwwCgYIKwYB
// SIG // BQUHAwgwDgYDVR0PAQH/BAQDAgeAMA0GCSqGSIb3DQEB
// SIG // CwUAA4ICAQAYGZa3aCDudbk9EVdkP8xcQGZuIAIPRx9K
// SIG // 1CA7uRzBt80fC0aWkuYYhQMvHHJRHUobSM4Uw3zN7fHE
// SIG // N8hhaBDb9NRaGnFWdtHxmJ9eMz6Jpn6KiIyi9U5Og7QC
// SIG // TZMl17n2w4eddq5vtk4rRWOVvpiDBGJARKiXWB9u2ix0
// SIG // WH2EMFGHqjIhjWUXhPgR4C6NKFNXHvWvXecJ2WXrJnvv
// SIG // QGXAfNJGETJZGpR41nUN3ijfiCSjFDxamGPsy5iYu904
// SIG // Hv9uuSXYd5m0Jxf2WNJSXkPGlNhrO27pPxgT111myAR6
// SIG // 1S3S2hc572zN9yoJEObE98Vy5KEM3ZX53cLefN81F1C9
// SIG // p/cAKkE6u9V6ryyl/qSgxu1UqeOZCtG/iaHSKMoxM7Mq
// SIG // 4SMFsPT/8ieOdwClYpcw0CjZe5KBx2xLa4B1neFib8J8
// SIG // /gSosjMdF3nHiyHx1YedZDtxSSgegeJsi0fbUgdzsVMJ
// SIG // YvqVw52WqQNu0GRC79ZuVreUVKdCJmUMBHBpTp6VFopL
// SIG // 0Jf4Srgg+zRD9iwbc9uZrn+89odpInbznYrnPKHiO26q
// SIG // e1ekNwl/d7ro2ItP/lghz0DoD7kEGeikKJWHdto7eVJo
// SIG // JhkrUcanTuUH08g+NYwG6S+PjBSB/NyNF6bHa/xR+ceA
// SIG // Yhcjx0iBiv90Mn0JiGfnA2/hLj5evhTcAjCCB3EwggVZ
// SIG // oAMCAQICEzMAAAAVxedrngKbSZkAAAAAABUwDQYJKoZI
// SIG // hvcNAQELBQAwgYgxCzAJBgNVBAYTAlVTMRMwEQYDVQQI
// SIG // EwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4w
// SIG // HAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xMjAw
// SIG // BgNVBAMTKU1pY3Jvc29mdCBSb290IENlcnRpZmljYXRl
// SIG // IEF1dGhvcml0eSAyMDEwMB4XDTIxMDkzMDE4MjIyNVoX
// SIG // DTMwMDkzMDE4MzIyNVowfDELMAkGA1UEBhMCVVMxEzAR
// SIG // BgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
// SIG // bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
// SIG // bjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAg
// SIG // UENBIDIwMTAwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAw
// SIG // ggIKAoICAQDk4aZM57RyIQt5osvXJHm9DtWC0/3unAcH
// SIG // 0qlsTnXIyjVX9gF/bErg4r25PhdgM/9cT8dm95VTcVri
// SIG // fkpa/rg2Z4VGIwy1jRPPdzLAEBjoYH1qUoNEt6aORmsH
// SIG // FPPFdvWGUNzBRMhxXFExN6AKOG6N7dcP2CZTfDlhAnrE
// SIG // qv1yaa8dq6z2Nr41JmTamDu6GnszrYBbfowQHJ1S/rbo
// SIG // YiXcag/PXfT+jlPP1uyFVk3v3byNpOORj7I5LFGc6XBp
// SIG // Dco2LXCOMcg1KL3jtIckw+DJj361VI/c+gVVmG1oO5pG
// SIG // ve2krnopN6zL64NF50ZuyjLVwIYwXE8s4mKyzbnijYjk
// SIG // lqwBSru+cakXW2dg3viSkR4dPf0gz3N9QZpGdc3EXzTd
// SIG // EonW/aUgfX782Z5F37ZyL9t9X4C626p+Nuw2TPYrbqgS
// SIG // Uei/BQOj0XOmTTd0lBw0gg/wEPK3Rxjtp+iZfD9M269e
// SIG // wvPV2HM9Q07BMzlMjgK8QmguEOqEUUbi0b1qGFphAXPK
// SIG // Z6Je1yh2AuIzGHLXpyDwwvoSCtdjbwzJNmSLW6CmgyFd
// SIG // XzB0kZSU2LlQ+QuJYfM2BjUYhEfb3BvR/bLUHMVr9lxS
// SIG // UV0S2yW6r1AFemzFER1y7435UsSFF5PAPBXbGjfHCBUY
// SIG // P3irRbb1Hode2o+eFnJpxq57t7c+auIurQIDAQABo4IB
// SIG // 3TCCAdkwEgYJKwYBBAGCNxUBBAUCAwEAATAjBgkrBgEE
// SIG // AYI3FQIEFgQUKqdS/mTEmr6CkTxGNSnPEP8vBO4wHQYD
// SIG // VR0OBBYEFJ+nFV0AXmJdg/Tl0mWnG1M1GelyMFwGA1Ud
// SIG // IARVMFMwUQYMKwYBBAGCN0yDfQEBMEEwPwYIKwYBBQUH
// SIG // AgEWM2h0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2lv
// SIG // cHMvRG9jcy9SZXBvc2l0b3J5Lmh0bTATBgNVHSUEDDAK
// SIG // BggrBgEFBQcDCDAZBgkrBgEEAYI3FAIEDB4KAFMAdQBi
// SIG // AEMAQTALBgNVHQ8EBAMCAYYwDwYDVR0TAQH/BAUwAwEB
// SIG // /zAfBgNVHSMEGDAWgBTV9lbLj+iiXGJo0T2UkFvXzpoY
// SIG // xDBWBgNVHR8ETzBNMEugSaBHhkVodHRwOi8vY3JsLm1p
// SIG // Y3Jvc29mdC5jb20vcGtpL2NybC9wcm9kdWN0cy9NaWNS
// SIG // b29DZXJBdXRfMjAxMC0wNi0yMy5jcmwwWgYIKwYBBQUH
// SIG // AQEETjBMMEoGCCsGAQUFBzAChj5odHRwOi8vd3d3Lm1p
// SIG // Y3Jvc29mdC5jb20vcGtpL2NlcnRzL01pY1Jvb0NlckF1
// SIG // dF8yMDEwLTA2LTIzLmNydDANBgkqhkiG9w0BAQsFAAOC
// SIG // AgEAnVV9/Cqt4SwfZwExJFvhnnJL/Klv6lwUtj5OR2R4
// SIG // sQaTlz0xM7U518JxNj/aZGx80HU5bbsPMeTCj/ts0aGU
// SIG // GCLu6WZnOlNN3Zi6th542DYunKmCVgADsAW+iehp4LoJ
// SIG // 7nvfam++Kctu2D9IdQHZGN5tggz1bSNU5HhTdSRXud2f
// SIG // 8449xvNo32X2pFaq95W2KFUn0CS9QKC/GbYSEhFdPSfg
// SIG // QJY4rPf5KYnDvBewVIVCs/wMnosZiefwC2qBwoEZQhlS
// SIG // dYo2wh3DYXMuLGt7bj8sCXgU6ZGyqVvfSaN0DLzskYDS
// SIG // PeZKPmY7T7uG+jIa2Zb0j/aRAfbOxnT99kxybxCrdTDF
// SIG // NLB62FD+CljdQDzHVG2dY3RILLFORy3BFARxv2T5JL5z
// SIG // bcqOCb2zAVdJVGTZc9d/HltEAY5aGZFrDZ+kKNxnGSgk
// SIG // ujhLmm77IVRrakURR6nxt67I6IleT53S0Ex2tVdUCbFp
// SIG // AUR+fKFhbHP+CrvsQWY9af3LwUFJfn6Tvsv4O+S3Fb+0
// SIG // zj6lMVGEvL8CwYKiexcdFYmNcP7ntdAoGokLjzbaukz5
// SIG // m/8K6TT4JDVnK+ANuOaMmdbhIurwJ0I9JZTmdHRbatGe
// SIG // Pu1+oDEzfbzL6Xu/OHBE0ZDxyKs6ijoIYn/ZcGNTTY3u
// SIG // gm2lBRDBcQZqELQdVTNYs6FwZvKhggNQMIICOAIBATCB
// SIG // +aGB0aSBzjCByzELMAkGA1UEBhMCVVMxEzARBgNVBAgT
// SIG // Cldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAc
// SIG // BgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjElMCMG
// SIG // A1UECxMcTWljcm9zb2Z0IEFtZXJpY2EgT3BlcmF0aW9u
// SIG // czEnMCUGA1UECxMeblNoaWVsZCBUU1MgRVNOOjk2MDAt
// SIG // MDVFMC1EOTQ3MSUwIwYDVQQDExxNaWNyb3NvZnQgVGlt
// SIG // ZS1TdGFtcCBTZXJ2aWNloiMKAQEwBwYFKw4DAhoDFQBL
// SIG // cI81gxbea1Ex2mFbXx7ck+0g/6CBgzCBgKR+MHwxCzAJ
// SIG // BgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAw
// SIG // DgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3Nv
// SIG // ZnQgQ29ycG9yYXRpb24xJjAkBgNVBAMTHU1pY3Jvc29m
// SIG // dCBUaW1lLVN0YW1wIFBDQSAyMDEwMA0GCSqGSIb3DQEB
// SIG // CwUAAgUA6dpNnjAiGA8yMDI0MDQyOTE2NDcyNloYDzIw
// SIG // MjQwNDMwMTY0NzI2WjB3MD0GCisGAQQBhFkKBAExLzAt
// SIG // MAoCBQDp2k2eAgEAMAoCAQACAg2YAgH/MAcCAQACAhJa
// SIG // MAoCBQDp258eAgEAMDYGCisGAQQBhFkKBAIxKDAmMAwG
// SIG // CisGAQQBhFkKAwKgCjAIAgEAAgMHoSChCjAIAgEAAgMB
// SIG // hqAwDQYJKoZIhvcNAQELBQADggEBAJsMGFki2DeHqAIJ
// SIG // g8p8wneMngX4s78go083eg6UkqsWGVKFgcP41+MX2yKY
// SIG // ij6FL5y8TCYDzBGbR/t8ASDXbLCU7U+4tmpG7JM1p2kl
// SIG // S/byTgdRb9fUcuaFNmcoMwBsMbGTukKvqOTHZUNkoQao
// SIG // yHc9KC8ORyoMXAuxr0yH7ThZtXBypdd7AvzvZ0eta8CG
// SIG // eZtYzO6KlBg7ESrkLrECnpJjQkoPODD/zNpPQGYtszBc
// SIG // CdREuzZJDTUSIXNaRr9XRXWBhYpNmk9rmhRqrzOS/a6V
// SIG // anLLpMuRK6SH54UVAb6Ox/nrWvvXQ+ZkgxL1bY+upsNI
// SIG // BF8AslS9Fhs5Hn1t0WkxggQNMIIECQIBATCBkzB8MQsw
// SIG // CQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQ
// SIG // MA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9z
// SIG // b2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1NaWNyb3Nv
// SIG // ZnQgVGltZS1TdGFtcCBQQ0EgMjAxMAITMwAAAe+JP1ah
// SIG // WMyo2gABAAAB7zANBglghkgBZQMEAgEFAKCCAUowGgYJ
// SIG // KoZIhvcNAQkDMQ0GCyqGSIb3DQEJEAEEMC8GCSqGSIb3
// SIG // DQEJBDEiBCChmqm0gePysXQpF/dEpV53ElL1XejGZ9Cm
// SIG // 3hAMo3l9+jCB+gYLKoZIhvcNAQkQAi8xgeowgecwgeQw
// SIG // gb0EIPBhKEW4Fo3wUz09NQx2a0DbcdsX8jovM5LizHmn
// SIG // yX+jMIGYMIGApH4wfDELMAkGA1UEBhMCVVMxEzARBgNV
// SIG // BAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQx
// SIG // HjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEm
// SIG // MCQGA1UEAxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAgUENB
// SIG // IDIwMTACEzMAAAHviT9WoVjMqNoAAQAAAe8wIgQgVLwP
// SIG // ulCudtRb23Z4bHARcO/44SVb4pFlkt7+7lqsdiEwDQYJ
// SIG // KoZIhvcNAQELBQAEggIAKhugbAN6yisZSm5er/4Hh2hA
// SIG // GVzSQfhWLdOTaAw6/xODamHFn1A/dOjg/q3/WqKGsp3W
// SIG // v8Zdek6E39iyvP7Tw6TlvVLljWyBgWobGwLt23K0iDW1
// SIG // x5AJchoCrBm9awOs/cFzeuL+jO2aXKnCsZTGGXmp14TJ
// SIG // gur8Y2QvCQTKTDpZFSR245jdpdnHojv4jMnPF5ipkrKJ
// SIG // TEJmsCNqZiNwWpEv4xK2d2eWUAVdQ0K5w8YfTnLDaZDF
// SIG // xDSu3+pqBzSToPeveMcEj93d58ZZs7uaDErF+/FR5+Wg
// SIG // hAZAk1LTHePHjPpi0/Ag0FNpMXjfXKYw8kIbRkz+zaIN
// SIG // YZR3Zi20PkEXHd+JEUE/nkFYznkDtOUeJ94uUr0JSxx9
// SIG // CI6+KTyXiJgGfW8MNnMzsVpg75UFZpt5qP4aFsaDj4fl
// SIG // t0k6/lgwqlS0jZOu9wbYl/Vt4skw1Wk9/2mJKy8skLBj
// SIG // Opdb4KOrv/glADyDhfX/KEr9JHXJYjyCkpW0G8xw7LwE
// SIG // ocqnEqqNdNP/hq4f6cv7OYGmoKk+QXYGZ6FfDhinnOnx
// SIG // /ns2FCNbx56Ycd7nUCw3r9dkDJzsfU2j6GgFneRNuEqn
// SIG // mnK2zhHHAG57VWtTNwIZw4JAbIiP5jgJKLCTbrkvKKVJ
// SIG // 8/p1fefBEt8E0SsX3WV/GRJrgzx46Wsmj4wkJ50lOoo=
// SIG // End signature block
